"""Dependency injection for FastAPI routes."""
from sqlalchemy.ext.asyncio import AsyncSession

from ..core.storage.database import get_db


async def get_session() -> AsyncSession:
    """Get database session dependency.
    
    Yields:
        Async database session
    """
    db = get_db()
    async with db.session() as session:
        yield session

